@@ -11,7 +11,8 @@ urllib3.disable_warnings()
 default init all modules
 """
 
-def init(app_id: str = None, local=False, url=None, init_all_modules=True) -> Bot:
+
+def init(app_id: str = None, local=False, url=None, name=None, init_all_modules=True) -> Bot:
     """
     创建bot，并返回实例
     """
@@ -31,7 +32,5 @@ def init(app_id: str = None, local=False, url=None, init_all_modules=True) -> Bo
     else:
         Config.base_url = Config.remote_url
 
-    bot = Bot(app_id, init_all_modules)
+    bot = Bot(app_id, init_all_modules, name=name)
     return bot
-
-
