@@ -14,9 +14,9 @@ class CallerBase:
     def __init__(self, app_id):
         self.app_id = app_id
         self.base_url = Config.base_url
-        self.robot_url = '{}:{}/{}'.format(Config.base_url, Config.robot_port, Config.robot_url)
+        self.robot_url = '{}/{}'.format(Config.base_url, Config.robot_url)
 
-    def call_module(self, module: str, text: str,online: bool=False) -> Answer:
+    def call_module(self, module: str, text: str, online: bool = False) -> Answer:
         """
         robot接口访问
         :param module: 模块名称
@@ -38,11 +38,18 @@ class CallerBase:
         }
         resp = requests.post(self.robot_url, headers=header, json=data)
         params = json.loads(resp.text)
-        answers = params['results']
-        if answers:
-            answer = answers[0]
-            return Answer(answer['answer'][0]['value'], answer['answer_score'])
-        return Answer(Config.backfill_speech, 60)
+        results = params['results']
+        if results:
+            result = results[0]
+            text = result['answer'][0]['value']
+            score = result['answer_score']
+            answer = Answer(text=text, score=score)
+            if len(result["answer"]) == 1:
+                return answer
+            answer_data = result['answer'][1]["data"]
+            answer.related = answer_data if answer_data else []
+            return answer
+        return Answer(text=Config.backfill_speech, score=60)
 
     @staticmethod
     def _response_failed(response):
