@@ -18,7 +18,7 @@ class Bot:
     机器人
     """
 
-    def __init__(self, app_id, init_module: bool):
+    def __init__(self, app_id, init_module: bool, name=None):
         self.app_id = app_id
         self.set = Set()
         self.intent = IntentAnswering(app_id, self.set, init_module)
@@ -28,7 +28,7 @@ class Bot:
         self.dm = DialogueManager(app_id, self.set, init_module)
         self.ner = NERParser(app_id, self.set, init_module)
         self.act = DialogueAct(app_id, self.set, init_module)
-        self.config = ConfigManager(app_id, self.set, init_module)
+        self.config = ConfigManager(app_id, self.set, init_module, name=name)
         self.statistic = LogStatistic(app_id, self.set, init_module)
         self.common_service = CommonService(app_id, self.set, init_module)
         self.chat = ChatService(app_id, self.set, init_module)
