@@ -7,7 +7,7 @@ class Module:
     """
     出话模块
     """
-    def __init__(self, app_id,name,set):
+    def __init__(self, app_id, name, set):
         self.app_id = app_id
         self.name = name
         self.set = set
@@ -28,3 +28,6 @@ class Module:
         runner = TestRunner(dataset, self)
         result = runner.run()
         return result
+
+    def init(self):
+        pass
