@@ -39,13 +39,14 @@ class QuestionAnswering(Module):
             if data:
                 # 清空FAQ
                 if not append:
-                    self._upload_question(self.faq_sq_empty_path, is_log=False)
-                    self._upload_corpus(self.faq_lq_empty_path, is_log=False)
+                    self.upload_question(self.faq_sq_empty_path, is_log=False)
+                    self.upload_corpus(self.faq_lq_empty_path, is_log=False)
                 self._upload_json(data)
             else:
-                self._upload_question(question_path,append)
+                if question_path:
+                    self.upload_question(question_path, append)
                 if corpus_path:
-                    self._upload_corpus(corpus_path,append)
+                    self.upload_corpus(corpus_path, append)
             return self._train(show_progress)
         except BfEngineException as bfe:
             log.error(bfe)
@@ -155,7 +156,7 @@ class QuestionAnswering(Module):
         except Exception as e:
             return None
 
-    def _upload_corpus(self, corpus_path, is_log: bool = True,append: bool = False):
+    def upload_corpus(self, corpus_path, is_log: bool = True, append: bool = False):
         """
         上传qa语料
         :param corpus_path 语料路径
@@ -168,7 +169,7 @@ class QuestionAnswering(Module):
             progress = self.caller.upload_status(data_id, is_log=is_log)
             time.sleep(1)
 
-    def _upload_question(self, question_path, is_log=True,append: bool = False):
+    def upload_question(self, question_path, is_log=True, append: bool = False):
         if not question_path:
             raise BfEngineException(ErrorCode.argument_missing_error, 'missing question path')
 
@@ -211,12 +212,12 @@ class QuestionAnswering(Module):
         lq_id = self.caller.add_corpus(question_id, corpus)
         return lq_id
 
-    def delete_corpus(self, corpus_id):
+    def delete_corpus(self,question_id, corpus_id):
         """
         删除语料
         :return:
         """
-        return self.caller.delete_corpus(corpus_id)
+        return self.caller.delete_corpus(question_id, corpus_id)
 
     def add_question(self, question_data: dict):
         """
